---
layout: default
title: Documentation
permalink: /doc/
redirect_from:
- /en/doc/
- /doc/UserDoc/
- /wiki/UserDoc/
- /doc/QubesDocs/
- /wiki/QubesDocs/
- /help/
- /en/help/
- /en/community/
- /community/
---

User Documentation
==================

The Basics
----------

 * [What is Qubes OS?](/intro/)
 * [Video Tours](/video-tours/)
 * [Screenshots](/screenshots/)
 * [Getting Started](/getting-started/)
 * [User FAQ](/doc/user-faq/)
 * [Mailing Lists](/mailing-lists/)
 * [Report a Security Issue](/security/)
 * [Report a Bug](/doc/reporting-bugs/)
 * [How to Contribute](/doc/contributing/)

Security Information
--------------------
 * [Security Main Page](/security/)
 * [Security Pack](/doc/security-pack/)
 * [Security Bulletins](/doc/security-bulletins/)
 * [Canaries](/doc/canaries/)
 * [Why and How to Verify Signatures](/doc/verifying-signatures/)
 * [Qubes PGP Keys](http://keys.qubes-os.org/keys/)

Choosing Your Hardware
----------------------

 * [System Requirements](/doc/system-requirements/)
 * [Hardware Compatibility List (HCL)](/hcl/)
 * [Qubes-Certified Laptops](/doc/certified-laptops/)
 * [Hardware Certification](/hardware-certification/)


Installing & Upgrading Qubes
----------------------------

 * [Qubes Downloads](/downloads/)
 * [Installation Guide](/doc/installation-guide/)
 * [Upgrade Guides](/doc/upgrade/)
 * [Why and How to Verify Signatures](/doc/verifying-signatures/)
 * [Security Considerations when Installing](/doc/install-security/)
 * [Try Qubes without installing: Qubes Live USB (alpha)](/doc/live-usb/)
 * [Supported Versions](/doc/supported-versions/)
 * [Version Scheme](/doc/version-scheme/)
 * [Custom Installation](/doc/custom-install/)

Common Tasks
------------

 * [Copying and Pasting Text Between Domains](/doc/copy-paste/)
 * [Copying and Moving Files Between Domains](/doc/copying-files/)
 * [Copying from (and to) dom0](/doc/copy-from-dom0/)
 * [Updating Software in dom0](/doc/software-update-dom0/)
 * [Updating and Installing Software in VMs](/doc/software-update-vm/)
 * [Backup, Restoration, and Migration](/doc/backup-restore/)
 * [Using Disposable VMs](/doc/dispvm/)
 * [Using and Managing USB Devices](/doc/usb/)
 * [Recording Optical Discs](/doc/recording-optical-discs/)
 * [Managing Application Shortcuts](/doc/managing-appvm-shortcuts/)
 * [Enabling Fullscreen Mode](/doc/full-screen-mode/)


Managing Operating Systems within Qubes
---------------------------------------

 * [TemplateVMs](/doc/templates/)
 * [Templates: Fedora](/doc/templates/fedora/)
 * [Templates: Fedora Minimal](/doc/templates/fedora-minimal/)
 * [Templates: Debian](/doc/templates/debian/)
 * [Templates: Archlinux](/doc/templates/archlinux/)
 * [Templates: Ubuntu](/doc/templates/ubuntu/)
 * [Templates: Whonix](/doc/whonix/)
 * [Pentesting](/doc/pentesting/)
 * [Pentesting: BlackArch](/doc/pentesting/blackarch/)
 * [Pentesting: Kali](/doc/pentesting/kali/)
 * [Pentesting: PTF](/doc/pentesting/ptf/)
 * [Windows: Installing and Using Windows-based AppVMs (Qubes R2 Beta 3 and later)](/doc/windows-appvms/)
 * [Windows: Creating and Using HVM and Windows Domains (Qubes R2+)](/doc/hvm/)
 * [Windows: Advanced options and troubleshooting of Qubes Tools for Windows (R3)](/doc/windows-tools-3/)
 * [Windows: Advanced options and troubleshooting of Qubes Tools for Windows (R2)](/doc/windows-tools-2/)
 * [Windows: Uninstalling Qubes Tools for Windows 2.x](/doc/uninstalling-windows-tools-2/)
 * [Fedora: Upgrading the Fedora 23 Template to Fedora 24](/doc/template/fedora/upgrade-23-to-24/)
 * [Fedora: Upgrading the Fedora 21 Template to Fedora 23](/doc/template/fedora/upgrade-21-to-23/)
 * [Fedora: Upgrading the Fedora 20 Template to Fedora 21](/doc/template/fedora/upgrade-20-to-21/)
 * [Fedora: Upgrading the Fedora 18 Template to Fedora 20](/doc/template/fedora/upgrade-18-to-20/)
 * [Debian: Upgrading the Debian 8 Template to Debian 9](/doc/template/debian/upgrade-8-to-9/)
 * [How to Reinstall a TemplateVM](/doc/reinstall-template)
 * [Tips for Using Linux in an HVM](/doc/linux-hvm-tips/)
 * [Creating a NetBSD VM](/doc/netbsd/)


Security Guides
---------------

 * [Qubes OS Project Security Information](/security/)
 * [Security Guidelines](/doc/security-guidelines/)
 * [Understanding Qubes Firewall](/doc/firewall/)
 * [Understanding and Preventing Data Leaks](/doc/data-leaks/)
 * [Installing Anti Evil Maid](/doc/anti-evil-maid/)
 * [Using Multi-factor Authentication with Qubes](/doc/multifactor-authentication/)
 * [Using GPG more securely in Qubes: Split GPG](/doc/split-gpg/)
 * [How to Set Up a Split Bitcoin Wallet in Qubes](/doc/split-bitcoin/)
 * [[Unofficial] Split dm-crypt](https://github.com/rustybird/qubes-split-dm-crypt)
 * [Configuring YubiKey for user authentication](/doc/yubi-key/)
 * [Note regarding password-less root access in VM](/doc/vm-sudo/)


Privacy Guides
--------------

 * [Whonix for Privacy & Anonymity](/doc/whonix/)
 * [Running Tails in Qubes](/doc/tails/)
 * [Anonymizing your MAC Address](/doc/anonymizing-your-mac-address/)
 * [TorVM](/doc/torvm/)
 * [Martus](/doc/martus/)
 * [Signal](/doc/signal/)


Configuration Guides
--------------------

 * [Configuration Files](/doc/config-files/)
 * [How to set up a ProxyVM as a VPN Gateway](/doc/vpn/)
 * [Storing AppVMs on Secondary Drives](/doc/secondary-storage/)
 * [Where are my external storage devices mounted?](/doc/external-device-mount-point/)
 * [Multibooting](/doc/multiboot/)
 * [Resizing AppVM and HVM Disk Images](/doc/resize-disk-image/)
 * [Extending `root.img` Size](/doc/resize-root-disk-image/)
 * [Installing ZFS in Qubes](/doc/zfs/)
 * [Mutt Guide](/doc/mutt/)
 * [Postfix Guide](/doc/postfix/)
 * [Fetchmail Guide](/doc/fetchmail/)
 * [Creating Custom NetVMs and ProxyVMs](http://theinvisiblethings.blogspot.com/2011/09/playing-with-qubes-networking-for-fun.html)
 * [How to make proxy for individual tcp connection from networkless VM](https://groups.google.com/group/qubes-devel/msg/4ca950ab6d7cd11a)
 * [Make an HTTP Filtering Proxy in a FirewallVM](/doc/config/http-filtering-proxy)
 * [Adding Bridge Support to the NetVM (EXPERIMENTAL)](/doc/network-bridge-support/)
 * [Assigning PCI Devices to AppVMs](/doc/assigning-devices/)
 * [Enabling TRIM for SSD disks](/doc/disk-trim/)
 * [Configuring a Network Printer](/doc/network-printer/)
 * [Using External Audio Devices](/doc/external-audio/)
 * [Booting with GRUB2 and GPT](https://groups.google.com/group/qubes-devel/browse_thread/thread/e4ac093cabd37d2b/d5090c20d92c4128#d5090c20d92c4128)
 * [Rxvt Guide](/doc/rxvt/)
 * [Managing VM kernel](/doc/managing-vm-kernel/)
 * [Salt management stack](/doc/salt/)
 * [Adding SSD storage cache](https://groups.google.com/d/msgid/qubes-users/a08359c9-9eb0-4d1a-ad92-a8a9bc676ea6%40googlegroups.com)


Customization Guides
--------------------

 * [DispVM Customization](/doc/dispvm-customization/)
 * [Customizing Fedora minimal templates](/doc/fedora-minimal-template-customization)
 * [Customizing Windows 7 templates](/doc/windows-template-customization)
 * [Using KDE in dom0](/doc/kde/)
 * [Installing XFCE in dom0](/doc/xfce/)
 * [Installing i3 in dom0](/doc/i3/)
 * [Language Localization](/doc/language-localization/)
 * [Dark Theme in Dom0 and DomU](/doc/dark-theme/)
 * [How to make any file in a TemplateBasedVM persistent using bind-dirs](/doc/bind-dirs/)


Troubleshooting
---------------

 * [Home directory is out of disk space error](/doc/out-of-memory/)
 * [Installing on system with new AMD GPU (missing firmware problem)](https://groups.google.com/group/qubes-devel/browse_thread/thread/e27a57b0eda62f76)
 * [How to install an Nvidia driver in dom0](/doc/install-nvidia-driver/)
 * [Nvidia troubleshooting guide](/doc/nvidia-troubleshooting/)
 * [Lenovo ThinkPad Troubleshooting](/doc/thinkpad-troubleshooting/)
 * [Apple MacBook Troubleshooting](/doc/macbook-troubleshooting/)
 * [Getting Sony Vaio Z laptop to work with Qubes](/doc/sony-vaio-tinkering/)
 * [Troubleshooting UEFI related problems](/doc/uefi-troubleshooting/)
 * [Fixing wireless on suspend & resume](/doc/wireless-troubleshooting/)


Reference Pages
---------------

 * [Dom0 Command-Line Tools](/doc/dom0-tools/)
 * [DomU Command-Line Tools](/doc/vm-tools/)
 * [Glossary of Qubes Terminology](/doc/glossary/)
 * [Qubes Service Framework](/doc/qubes-service/)
 * [Command Execution in VMs (and Qubes RPC)](/doc/qrexec/)


Presentation Slides
-------------------
 * [[PDF] LinuxCon 2014 -- Qubes OS R2 Tutorial](/attachment/wiki/slides/LinuxCon_2014_Qubes_Tutorial.pdf)
 * [[PDF] LinuxCon 2014 -- Qubes OS Keynote](/attachment/wiki/slides/LinuxCon_2014_Qubes_Keynote.pdf)
 * [[PDF] RMLL 2016 -- Improving client systems security with Qubes OS](/attachment/wiki/slides/RMLL_2016_Improving-client-systems-security.pdf)

Developer Documentation
=======================

The Basics
----------

 * [Developer FAQ](/doc/devel-faq/)
 * [Report a Security Issue](/security/)
 * [Report a Bug](/doc/reporting-bugs/)
 * [How to Contribute](/doc/contributing/)
 * [Source Code](/doc/source-code/)
 * [Qubes OS License](/doc/license/)
 * [Coding Guidelines](/doc/coding-style/)
 * [Documentation Guidelines](/doc/doc-guidelines/)
 * [Code Signing](/doc/code-signing/)
 * [Feature Development Tracker](/qubes-issues/)
 * [Books for Developers](/doc/devel-books/)
 * [Style Guide](/doc/style-guide/)
 * [Usability & UX](/doc/usability-ux/)

Security Information
--------------------
 * [Security Main Page](/security/)
 * [Security Goals](/doc/security-goals/)
 * [Security Pack](/doc/security-pack/)
 * [Security Bulletins](/doc/security-bulletins/)
 * [Security Bulletin Checklist](/doc/security-bulletins/checklist/)
 * [Security Bulletin Template](/doc/security-bulletins/template/)
 * [Canaries](/doc/canaries/)
 * [Why and How to Verify Signatures](/doc/verifying-signatures/)
 * [Qubes PGP Keys](http://keys.qubes-os.org/keys/)

System
------
 * [Qubes OS Architecture Overview](/doc/architecture/)
 * [Qubes OS Architecture Spec v0.3 [PDF]](/attachment/wiki/QubesArchitecture/arch-spec-0.3.pdf)
 * [Security-critical elements of Qubes OS](/doc/security-critical-code/)
 * [Qrexec: command execution in VMs](/doc/qrexec3/)
 * [Qubes GUI virtualization protocol](/doc/gui/)
 * [Networking in Qubes](/doc/networking/)
 * [Implementation of template sharing and updating](/doc/template-implementation/)
 * [Storage Pools](/doc/storage-pools/)

Services
--------
 * [Inter-domain file copying](/doc/qfilecopy/) (deprecates [`qfileexchgd`](/doc/qfileexchgd/))
 * [Dynamic memory management in Qubes](/doc/qmemman/)
 * [Implementation of DisposableVMs](/doc/dvm-impl/)
 * [Article about disposable VMs](http://theinvisiblethings.blogspot.com/2010/06/disposable-vms.html)
 * [Dom0 secure update mechanism](/doc/dom0-secure-updates/)
 * VM secure update mechanism (forthcoming)

Debugging
---------
 * [Profiling python code](/doc/profiling/)
 * [Test environment in separate machine for automatic tests](/doc/test-bench/)
 * [Automated tests](/doc/automated-tests/)
 * [VM-dom0 internal configuration interface](/doc/vm-interface/)
 * [Debugging Windows VMs](/doc/windows-debugging/)
 * [Safe Remote Dom0 Terminals](/doc/safe-remote-ttys/)

Building
--------
 * [Building Qubes](/doc/qubes-builder/) (["API" Details](/doc/qubes-builder-details/))
 * [Development Workflow](/doc/development-workflow/)
 * [Building Qubes OS 3.0 ISO](/doc/qubes-r3-building/)
 * [Building USB passthrough support (experimental)](/doc/pvusb/)
 * [Building Qubes Templates](https://github.com/QubesOS/qubes-template-configs)
 * [Building a TemplateVM based on a new OS (ArchLinux example)](/doc/building-non-fedora-template/)
 * [Building the Archlinux Template](/doc/building-archlinux-template/)

Releases
--------
 * [Release checklist](/doc/releases/todo/)
 * [Qubes R1.0 release notes](/doc/releases/1.0/release-notes/)
 * [Qubes R2.0 release notes](/doc/releases/2.0/release-notes/)
 * [Qubes R3.0 release notes](/doc/releases/3.0/release-notes/)
 * [Qubes R3.0 release schedule](/doc/releases/3.0/schedule/)
 * [Qubes R3.1 release notes](/doc/releases/3.1/release-notes/)
 * [Qubes R3.1 release schedule](/doc/releases/3.1/schedule/)
 * [Qubes R3.2 release notes](/doc/releases/3.2/release-notes/)
 * [Qubes R3.2 release schedule](/doc/releases/3.2/schedule/)

